import axios from "axios"

const feature_type = {
  namespaced: true,
  state: {
    form: null,
    colorsStyleList: [],
    customForms: [],
    current_feature_type_slug: null,
    feature_types: [],
    filenameToImport: null,
    importFeatureTypeData: [],
  },

  mutations: {
    SET_FEATURE_TYPES(state, feature_types) {
      state.feature_types = feature_types;
    },
    SET_CURRENT_FEATURE_TYPE_SLUG(state, payload) {
      state.current_feature_type_slug = payload;
    },
    UPDATE_FORM(state, payload) {
      state.form = payload;
    },
    EMPTY_FORM(state) {
      state.form = null;
    },
    ADD_CUSTOM_FORM(state, customForm) {
      state.customForms = [...state.customForms, customForm];
    },
    UPDATE_CUSTOM_FORM(state, payload) {
      const index = state.customForms.findIndex((el) => el.dataKey === payload.dataKey);
      if (index !== -1) state.customForms[index] = payload
    },
    REMOVE_CUSTOM_FORM(state, payload) {
      state.customForms = state.customForms.filter(form => form.dataKey !== payload);
    },
    EMPTY_CUSTOM_FORMS(state) {
      state.customForms = [];
    },
    UPDATE_COLOR_STYLE(state) { // * un peu dirty (mais pas quick) car getter pas réactif avec nested et compliqué de faire dans composants enfants multiples
      let res = [];
      for (let form of state.customForms) {
        if (form.label) res.push(form);
      }
      state.colorsStyleList = res;
    },
    SET_IMPORT_FEATURE_TYPES_DATA(state, payload) {
      state.importFeatureTypeData = payload;
    },
    SET_FILE_NAME_TO_IMPORT(state, payload) {
      state.filenameToImport = payload;
    },
  },
  getters: {
    feature_type: state => state.feature_types.find(
      (el) => el.slug === state.current_feature_type_slug
    )
  },
  actions: {
    async POST_FEATURE_TYPE({ state, rootGetters }) {
      const data = {
        'title': state.form.title.value,
        'slug': rootGetters.project.slug,
        'geom_type': state.form.geom_type.value,
        'color': state.form.color.value,
        'colors_style': state.form.colors_style.value,
        'project': rootGetters.project.slug,
        //'project': state.form.project.value,
        'customfield_set': state.customForms.map(el => {
          return {
            'position': el.position,
            'label': el.label,
            'name': el.name,
            'field_type': el.field_type,
            'options': el.options,
          }
        }),
        //'is_editable': true,
      }
      //console.log("data", data)

      return axios
        .post(`${process.env.VUE_APP_DJANGO_API_BASE}feature-types/`, data)
        .then((response) => {
          const feature_type_slug = response.data.slug;
          const status = response.status;
          return { feature_type_slug, status };
        })
        .catch((error) => {
          console.error(error);
        });
    },

    POST_FEATURES_FROM_GEOJSON({ state, dispatch }, payload) {
      const { feature_type_slug } = payload

      if (state.filenameToImport.size > 0) {
        var formData = new FormData();
        formData.append("json_file", state.filenameToImport);
        formData.append("feature_type_slug", feature_type_slug);
        let url =
          process.env.VUE_APP_DJANGO_API_BASE +
          'import-tasks/'
        return axios
          .post(url, formData, {
            headers: {
              "Content-Type": "multipart/form-data",
            },
          })
          .then((response) => {
            console.log(response)
            if (response.status === 200) {
              dispatch("GET_IMPORTS", feature_type_slug);
              // TODO : RELOAD DERNIER SIGNALEMENTS
            }
            return response
          })
          .catch((err) => {
            // TODO : HANDLER ERROR
            console.log(err);
          });
      }
    },

    GET_IMPORTS({ commit }, feature_type) {
      let url =
        process.env.VUE_APP_DJANGO_API_BASE +
        "import-tasks?feature_type_slug=" +
        feature_type;
      axios
        .get(url)
        .then((response) => {
          commit("SET_IMPORT_FEATURE_TYPES_DATA", response.data);
        })
        .catch((err) => {
          console.log(err);
        });
    }
  }
}

export default feature_type